# Metadata for the widget EGG. Should leave it for the (unimplemented) widget
# tracker to track it

__DISTRIBUTION__ = 'tw.timeline'
__DESCRIPTION__ = 'Timeline Widget application'
__URL__ = ''
__VERSION__ = '0.1a0'
__AUTHOR__ = 'Christopher Perkins'
__EMAIL__ = 'chris@percious.com'
__COPYRIGHT__ = "Copyright 2008 Christopher Perkins"
__LICENSE__ = 'MIT'



"""
Here you can create samples of your widgets by providing default parameters,
inserting them in a container widget, mixing them with other widgets, etc...
These samples will appear in the WidgetBrowser

See http://toscawidgets.org/documentation/WidgetBrowser for more information
"""

from tw.timeline import Timeline

class DemoTimeline(Timeline):
    # Provide default parameters, value, etc... here
    # default = <some-default-value>
    pass



import os
import tw
from tw.api import Widget, JSLink, CSSLink, Link
from tw.core.resources import registry, working_set, Requirement
from defaults import __TIMELINE_VERSION__

class TimelineLinkMixin(Link):
    params = {'version': '(string) select the yui version you would like to use. Default version is: '+__TIMELINE_VERSION__,
    }

    extension = 'js'
    version = __TIMELINE_VERSION__

    def __init__(self, *args, **kw):
        super(Link, self).__init__(*args, **kw)
        modname = self.modname or self.__module__
        self.webdir, self.dirname, self.link = registry.register(
            modname, self.filename
            )

    
    def _get_link(self):
        return tw.framework.url(self._link or '')

    def _set_link(self, link):
        self._link = link

    link = property(_get_link, _set_link)

    def abspath(self, filename):
        return os.sep.join((os.path.dirname(__file__), filename))

    def try_filename(self, filename):
        abspath = self.abspath(filename)
        if os.path.exists(abspath):
            return filename
        return False

    @property
    def filename(self):
        #make basename windows/qnix compat
        basename = self.basename.replace('/', os.sep)
        basename = self.basename.replace('\\', os.sep)

        basename = os.sep.join(('static', self.version, 'api', basename))
        #try the default
        filename =  basename+'.'+self.extension
        if self.try_filename(filename):
            return filename
        
        raise NotImplementedError('could not find a javascript file in the library with that name')
    


class TimelineJSLink(JSLink, TimelineLinkMixin):
    pass

class TimelineCSSLink(TimelineLinkMixin, CSSLink):
    extension = 'css'



from base import TimelineCSSLink, TimelineJSLink, JSLink

#class fonts_css(YUICSSLink):
#    basename="fonts/fonts"

class timeline_api_js(TimelineJSLink):
    basename = "timeline-api"
    javascript=[]
    css=[]

demo_js = JSLink(modname=__name__, filename="static/2.2.0/demo.js")